==> maven-dependency-plugin-3.3.0-source-release.zip: maven-dependency-plugin-3.3.0/src/test/java/org/apache/maven/plugins/dependency/testUtils/stubs/StubSourcesFileMarkerHandler.java <==
package org.apache.maven.plugins.dependency.testUtils.stubs;

/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.    
 */

import java.io.File;

import org.apache.maven.artifact.Artifact;
import org.apache.maven.plugins.dependency.utils.markers.SourcesFileMarkerHandler;

public class StubSourcesFileMarkerHandler
    extends SourcesFileMarkerHandler
{

    public StubSourcesFileMarkerHandler( Artifact artifact, File markerFilesDirectory, boolean resolved )
    {
        super( artifact, markerFilesDirectory, resolved );
    }

    protected File getMarkerFile( boolean res )
    {
        String suffix;
        if ( res )
        {
            suffix = ".resolved";
        }
        else
        {
            suffix = ".unresolved";
        }

        return new StubMarkerFile( this.markerFilesDirectory, this.artifact.getId().replace( ':', '-' ) + suffix );
    }

}

==> maven-dependency-plugin-3.10.0-source-release.zip: maven-dependency-plugin-3.10.0/src/test/java/org/apache/maven/plugins/dependency/testUtils/stubs/StubSourcesFileMarkerHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.plugins.dependency.testUtils.stubs;

import java.io.File;

import org.apache.maven.artifact.Artifact;
import org.apache.maven.plugins.dependency.utils.markers.SourcesFileMarkerHandler;

public class StubSourcesFileMarkerHandler extends SourcesFileMarkerHandler {

    public StubSourcesFileMarkerHandler(Artifact artifact, File markerFilesDirectory, boolean resolved) {
        super(artifact, markerFilesDirectory, resolved);
    }

    protected File getMarkerFile(boolean res) {
        String suffix;
        if (res) {
            suffix = ".resolved";
        } else {
            suffix = ".unresolved";
        }

        return new StubMarkerFile(
                this.markerFilesDirectory, this.artifact.getId().replace(':', '-') + suffix);
    }
}
